<?PHP
/**
 * Constains lists for categorizing event types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides a list for finding the respective event type ID for a given event type name.
 */
final class MDConcEventTypes implements MDImporterConcordanceListInterface {

    private const EVENT_TYPE_NAMES_TO_ID = [

        // 1: Created
        'Hergestellt' => 1,
        'Herstellung' => 1,
        'Production' => 1,
        'Bearbeitung' => 1,
        'Beginning of existence'  => 1,
        'creation'                => 1,
        'Erschaffung/Herstellung' => 1,
        'http://terminology.lido-schema.org/eventType/production' => 1,

        // 2: Was found
        'Auffinden' => 2,
        'Ausgrabung' => 2,
        'Finding' => 2,
        'Fund' => 2,
        'Fund (Aktivität)' => 2,
        'Gefunden' => 2,

        // 3: Published
        // 4: Template creation
        // 5: Displayed actor
        // 6: Was used
        'Aufführung' => 6,
        'Ausstellung' => 6,
        'Verwendungsort' => 6,
        'Wurde genutzt' => 6,
        'gebrauch' => 6,
        'Gebrauch' => 6,
        'Use' => 6,
        'http://terminology.lido-schema.org/eventType/use' => 6,

        // 7: Written

        // 8: Collected
        'Collected' => 8,
        'Gesammelt' => 8,
        'Sammeln' => 8,
        'Collecting' => 8,
        'Sammeltätigkeit' => 8,

        // 9: => Painted

        // 10: Recorded
        'Fotografische Aufnahme' => 10,
        'Aufnahme' => 10,
        'Aufgenommen' => 10,

        // 20: Copied
        // 21: Lived

        // 22: Related place
        'Geografischer Bezug' => 22,
        'Geografika' => 22,
        'Karteninhalt' => 22,

        // 25: Commissioned
        'Auftrag' => 25,
        'Commissioning' => 25,
        'Beauftragung' => 25,
        'Beauftragt' => 25,

        // 35: Intellectual creation
        'Design' => 35,
        'design' => 35,
        'Designing' => 35,
        'Entwerfen' => 35,
        'Entwurf' => 35,
        'Kulturelle Zuschreibung' => 35,
        'Merkmalszuweisung' => 35,
        'http://terminology.lido-schema.org/lido00024' => 35,
        'http://terminology.lido-schema.org/lido00224' => 35,

        // 41: Was Bought
        'Erwerb' => 41,
        'Erwerbung' => 41,
        'Acquisition (Activity)' => 41,
        'Bodenreform' => 41,

        // 43: Was sold
        'Kauf' => 43,

        // 49: Gifted, donated
        'Schenkung' => 49,
        'Nachlass' => 49,
        'Übergabe' => 49,

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return integer
     */
    public static function getConcordanceTarget(string $input):int {

        if (!isset(self::EVENT_TYPE_NAMES_TO_ID[$input])) {
            throw new MDImporterMissingConcordance("Unknown event type: '" . $input . "'");
        }

        return self::EVENT_TYPE_NAMES_TO_ID[$input];

    }
}
